@@ -13,24 +13,30 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5684 $
-## |  Last changed: $Date: 2022-01-05 12:27:24 +0100 (Mi, 05 Jan 2022) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 7126 $
+## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  Last changed by: $Author: pahlke $
 ## |
 ## |
 
-# @title
-# Get Analysis Results Survival
-#
-# @description
-# Returns an analysis result object.
-#
-# @param design The trial design.
-#
-# @return Returns a \code{AnalysisResultsSurvival} object.
-#
-# @keywords internal
-#
+#' @include f_logger.R
+NULL
+
+#'
+#' @title
+#' Get Analysis Results Survival
+#'
+#' @description
+#' Returns an analysis result object.
+#'
+#' @param design The trial design.
+#'
+#' @return Returns a \code{AnalysisResultsSurvival} object.
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
 .calcSurvivalTestStatistics <- function(dataInput, subset, stage, thetaH0,
         stratifiedAnalysis, directionUpper = TRUE) {
     overallEvents <- NA_real_
@@ -146,7 +152,7 @@
 
     .assertIsValidIntersectionTestEnrichment(design, intersectionTest)
 
-    if ((gMax > 2) && intersectionTest == "SpiessensDebois") {
+    if (gMax > 2 && intersectionTest == "SpiessensDebois") {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "gMax (", gMax,
             ") > 2: Spiessens & Debois intersection test test can only be used for one subset"
@@ -156,11 +162,11 @@
     if (!stratifiedAnalysis) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-            "Only stratified analysis can be performed for enrichment survival designs"
+            "only stratified analysis can be performed for enrichment survival designs"
         )
     }
 
-    if (dataInput$isStratified() && (gMax > 4)) {
+    if (dataInput$isStratified() && gMax > 4) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "gMax (", gMax,
             ") > 4: Stratified analysis not implemented"
@@ -306,7 +312,7 @@
         ))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessageEnrichment(design)
 }
 
 .getAnalysisResultsSurvivalInverseNormalEnrichment <- function(...,
@@ -368,6 +374,9 @@
     )
 
     results <- AnalysisResultsEnrichmentFisher(design = design, dataInput = dataInput)
+    .setValueAndParameterType(results, "iterations", as.integer(iterations), C_ITERATIONS_DEFAULT)
+    .setValueAndParameterType(results, "seed", seed, NA_real_)
+
     results <- .getAnalysisResultsSurvivalEnrichmentAll(
         results = results, design = design, dataInput = dataInput,
         intersectionTest = intersectionTest, stage = stage, directionUpper = directionUpper,
@@ -413,36 +422,25 @@
     .logProgress("Closed test calculated", startTime = startTime)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
-            conditionalPowerResults <- .getConditionalPowerSurvivalEnrichment(
+            results$.conditionalPowerResults <- .getConditionalPowerSurvivalEnrichment(
                 stageResults = stageResults,
                 stage = stage, nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 thetaH1 = thetaH1, iterations = iterations, seed = seed
             )
-            if (conditionalPowerResults$simulated) {
-                results$conditionalPowerSimulated <- conditionalPowerResults$conditionalPower
-                results$.setParameterType("conditionalPower", C_PARAM_NOT_APPLICABLE)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_GENERATED)
-            } else {
-                results$conditionalPower <- conditionalPowerResults$conditionalPower
-                results$conditionalPowerSimulated <- matrix(numeric(0))
-                results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_NOT_APPLICABLE)
-            }
+            .synchronizeIterationsAndSeed(results)
         } else {
-            conditionalPowerResults <- .getConditionalPowerSurvivalEnrichment(
+            results$.conditionalPowerResults <- .getConditionalPowerSurvivalEnrichment(
                 stageResults = stageResults,
                 stage = stage, nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 thetaH1 = thetaH1
             )
-            results$conditionalPower <- conditionalPowerResults$conditionalPower
+            results$conditionalPower <- results$.conditionalPowerResults$conditionalPower
             results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
         }
-        results$thetaH1 <- matrix(conditionalPowerResults$thetaH1, ncol = 1)
-        results$.conditionalPowerResults <- conditionalPowerResults
+        results$thetaH1 <- matrix(results$.conditionalPowerResults$thetaH1, ncol = 1)
         .logProgress("Conditional power calculated", startTime = startTime)
 
         # CRP - conditional rejection probabilities
@@ -607,13 +605,12 @@
     stages <- (1:stage)
     for (k in stages) {
         startTime <- Sys.time()
-        for (g in 1:gMax) {
-            if (!is.na(stageResults$testStatistics[g, k])) {
-
+        for (population in 1:gMax) {
+            if (!is.na(stageResults$testStatistics[population, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
                 # Finding maximum upper and minimum lower bounds for RCIs
                 thetaLow <- exp(.getUpperLowerThetaSurvivalEnrichment(
                     design = design, dataInput = dataInput,
-                    theta = -1, treatmentArm = g, stage = k, directionUpper = TRUE,
+                    theta = -1, treatmentArm = population, stage = k, directionUpper = TRUE,
                     stratifiedAnalysis = stratifiedAnalysis, intersectionTest = intersectionTest,
                     conditionFunction = conditionFunction, firstParameterName = firstParameterName,
                     secondValue = criticalValues[k]
@@ -621,31 +618,31 @@
 
                 thetaUp <- exp(.getUpperLowerThetaSurvivalEnrichment(
                     design = design, dataInput = dataInput,
-                    theta = 1, treatmentArm = g, stage = k, directionUpper = FALSE,
+                    theta = 1, treatmentArm = population, stage = k, directionUpper = FALSE,
                     stratifiedAnalysis = stratifiedAnalysis, intersectionTest = intersectionTest,
                     conditionFunction = conditionFunction, firstParameterName = firstParameterName,
                     secondValue = criticalValues[k]
                 ))
 
                 # finding upper and lower RCI limits through root function
-                repeatedConfidenceIntervals[g, 1, k] <- .getRootThetaSurvivalEnrichment(
+                repeatedConfidenceIntervals[population, 1, k] <- .getRootThetaSurvivalEnrichment(
                     design = design,
-                    dataInput = dataInput, treatmentArm = g, stage = k, directionUpper = TRUE,
+                    dataInput = dataInput, treatmentArm = population, stage = k, directionUpper = TRUE,
                     thetaLow = thetaLow, thetaUp = thetaUp, stratifiedAnalysis = stratifiedAnalysis,
                     intersectionTest = intersectionTest, firstParameterName = firstParameterName,
                     secondValue = criticalValues[k], tolerance = tolerance
                 )
 
-                repeatedConfidenceIntervals[g, 2, k] <- .getRootThetaSurvivalEnrichment(
+                repeatedConfidenceIntervals[population, 2, k] <- .getRootThetaSurvivalEnrichment(
                     design = design,
-                    dataInput = dataInput, treatmentArm = g, stage = k, directionUpper = FALSE,
+                    dataInput = dataInput, treatmentArm = population, stage = k, directionUpper = FALSE,
                     thetaLow = thetaLow, thetaUp = thetaUp, stratifiedAnalysis = stratifiedAnalysis,
                     intersectionTest = intersectionTest, firstParameterName = firstParameterName,
                     secondValue = criticalValues[k], tolerance = tolerance
                 )
 
                 # adjustment for binding futility bounds
-                if (k > 1 && conditionFunction(bounds[k - 1], border) & design$bindingFutility) {
+                if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
                     parameterName <- ifelse(.isTrialDesignFisher(design),
                         "singleStepAdjustedPValues", firstParameterName
                     )
@@ -657,7 +654,7 @@
                         thetaUp <- .getUpperLowerThetaSurvivalEnrichment(
                             design = design,
                             dataInput = dataInput,
-                            theta = 1, treatmentArm = g, stage = k - 1, directionUpper = FALSE,
+                            theta = 1, treatmentArm = population, stage = k - 1, directionUpper = FALSE,
                             conditionFunction = conditionFunction, stratifiedAnalysis = stratifiedAnalysis,
                             intersectionTest = intersectionTest, firstParameterName = parameterName,
                             secondValue = bounds[k - 1]
@@ -666,29 +663,29 @@
 
                     futilityCorr[k] <- .getRootThetaSurvivalEnrichment(
                         design = design, dataInput = dataInput,
-                        treatmentArm = g, stage = k - 1, directionUpper = directionUpper,
+                        treatmentArm = population, stage = k - 1, directionUpper = directionUpper,
                         thetaLow = thetaLow, thetaUp = thetaUp, stratifiedAnalysis = stratifiedAnalysis,
                         intersectionTest = intersectionTest, firstParameterName = parameterName,
                         secondValue = bounds[k - 1], tolerance = tolerance
                     )
 
                     if (directionUpper) {
-                        repeatedConfidenceIntervals[g, 1, k] <- min(
+                        repeatedConfidenceIntervals[population, 1, k] <- min(
                             min(futilityCorr[2:k]),
-                            repeatedConfidenceIntervals[g, 1, k]
+                            repeatedConfidenceIntervals[population, 1, k]
                         )
                     } else {
-                        repeatedConfidenceIntervals[g, 2, k] <- max(
+                        repeatedConfidenceIntervals[population, 2, k] <- max(
                             max(futilityCorr[2:k]),
-                            repeatedConfidenceIntervals[g, 2, k]
+                            repeatedConfidenceIntervals[population, 2, k]
                         )
                     }
                 }
 
-                if (!is.na(repeatedConfidenceIntervals[g, 1, k]) &&
-                        !is.na(repeatedConfidenceIntervals[g, 2, k]) &&
-                        repeatedConfidenceIntervals[g, 1, k] > repeatedConfidenceIntervals[g, 2, k]) {
-                    repeatedConfidenceIntervals[g, , k] <- rep(NA_real_, 2)
+                if (!is.na(repeatedConfidenceIntervals[population, 1, k]) &&
+                        !is.na(repeatedConfidenceIntervals[population, 2, k]) &&
+                        repeatedConfidenceIntervals[population, 1, k] > repeatedConfidenceIntervals[population, 2, k]) {
+                    repeatedConfidenceIntervals[population, , k] <- rep(NA_real_, 2)
                 }
             }
         }
@@ -698,9 +695,11 @@
     return(repeatedConfidenceIntervals)
 }
 
-#
-# RCIs based on inverse normal combination test
-#
+#'
+#' RCIs based on inverse normal combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalEnrichmentInverseNormal <- function(...,
         design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
@@ -724,9 +723,11 @@
     ))
 }
 
-#
-# RCIs based on Fisher's combination test
-#
+#'
+#' RCIs based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalEnrichmentFisher <- function(...,
         design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
@@ -750,9 +751,11 @@
     ))
 }
 
-#
-#  Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Survival
-#
+#'
+#' Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Survival
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalEnrichment <- function(..., design) {
     if (.isTrialDesignInverseNormal(design)) {
         return(.getRepeatedConfidenceIntervalsSurvivalEnrichmentInverseNormal(design = design, ...))
@@ -762,12 +765,14 @@
         return(.getRepeatedConfidenceIntervalsSurvivalEnrichmentFisher(design = design, ...))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessageEnrichment(design)
 }
 
-#
-#  Calculation of conditional power for Survival
-#
+#'
+#' Calculation of conditional power for Survival
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalEnrichment <- function(..., stageResults, stage = stageResults$stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaH1 = NA_real_,
@@ -848,9 +853,11 @@
     )
 }
 
-#
-# Calculation of conditional power based on inverse normal method
-#
+#'
+#' Calculation of conditional power based on inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalEnrichmentInverseNormal <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1) {
     .assertIsTrialDesignInverseNormal(design)
@@ -879,16 +886,16 @@
     ctr <- .performClosedCombinationTest(stageResults = stageResults)
     criticalValues <- design$criticalValues
 
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
+    for (population in 1:gMax) {
+        if (!is.na(ctr$separatePValues[population, stage])) {
             # shifted decision region for use in getGroupSeqProbs
             # Inverse Normal Method
             shiftedDecisionRegionUpper <- criticalValues[(stage + 1):kMax] *
                 sqrt(sum(weights[1:stage]^2) + cumsum(weights[(stage + 1):kMax]^2)) /
                 sqrt(cumsum(weights[(stage + 1):kMax]^2)) -
-                min(ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage], na.rm = TRUE) *
+                min(ctr$overallAdjustedTestStatistics[ctr$indices[, population] == 1, stage], na.rm = TRUE) *
                     sqrt(sum(weights[1:stage]^2)) /
-                    sqrt(cumsum(weights[(stage + 1):kMax]^2)) - standardizedEffect[g] *
+                    sqrt(cumsum(weights[(stage + 1):kMax]^2)) - standardizedEffect[population] *
                     cumsum(sqrt(nPlanned[(stage + 1):kMax]) * weights[(stage + 1):kMax]) /
                     sqrt(cumsum(weights[(stage + 1):kMax]^2))
             if (stage == kMax - 1) {
@@ -897,9 +904,9 @@
                 shiftedFutilityBounds <- design$futilityBounds[(stage + 1):(kMax - 1)] *
                     sqrt(sum(weights[1:stage]^2) + cumsum(weights[(stage + 1):(kMax - 1)]^2)) /
                     sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) -
-                    min(ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage], na.rm = TRUE) *
+                    min(ctr$overallAdjustedTestStatistics[ctr$indices[, population] == 1, stage], na.rm = TRUE) *
                         sqrt(sum(weights[1:stage]^2)) /
-                        sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) - standardizedEffect[g] *
+                        sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) - standardizedEffect[population] *
                         cumsum(sqrt(nPlanned[(stage + 1):(kMax - 1)]) * weights[(stage + 1):(kMax - 1)]) /
                         sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2))
             }
@@ -918,7 +925,7 @@
                 informationRates = scaledInformation
             )
 
-            results$conditionalPower[g, (stage + 1):kMax] <- cumsum(probs[3, ] - probs[2, ])
+            results$conditionalPower[population, (stage + 1):kMax] <- cumsum(probs[3, ] - probs[2, ])
         }
     }
 
@@ -932,9 +939,11 @@
     return(results)
 }
 
-#
-# Calculation of conditional power based on Fisher's combination test
-#
+#'
+#' Calculation of conditional power based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalEnrichmentFisher <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1, iterations, seed) {
     .assertIsTrialDesignFisher(design)
@@ -968,13 +977,13 @@
     nPlanned <- c(rep(NA_real_, stage), nPlanned)
     nPlanned <- allocationRatioPlanned / (1 + allocationRatioPlanned)^2 * nPlanned
     ctr <- .performClosedCombinationTest(stageResults = stageResults)
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
+    for (population in 1:gMax) {
+        if (!is.na(ctr$separatePValues[population, stage])) {
             if (gMax == 1) {
-                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, g] == 1, ][1:stage]
+                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, population] == 1, ][1:stage]
             } else {
-                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, g] == 1, ][which.max(
-                    ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage]
+                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, population] == 1, ][which.max(
+                    ctr$overallAdjustedTestStatistics[ctr$indices[, population] == 1, stage]
                 ), 1:stage]
             }
             if (stage < kMax - 1) {
@@ -984,11 +993,11 @@
                         reject <- reject + .getRejectValueConditionalPowerFisher(
                             kMax = kMax, alpha0Vec = design$alpha0Vec,
                             criticalValues = criticalValues, weightsFisher = weightsFisher,
-                            pValues = pValues, currentKMax = k, thetaH1 = standardizedEffect[g],
+                            pValues = pValues, currentKMax = k, thetaH1 = standardizedEffect[population],
                             stage = stage, nPlanned = nPlanned
                         )
                     }
-                    results$conditionalPower[g, k] <- reject / iterations
+                    results$conditionalPower[population, k] <- reject / iterations
                 }
                 results$simulated <- TRUE
                 results$.setParameterType("simulated", C_PARAM_GENERATED)
@@ -998,10 +1007,10 @@
 
                 if (result <= 0 || result >= 1) {
                     warning("Calculation not possible: could not calculate conditional power for stage ", kMax, call. = FALSE)
-                    results$conditionalPower[g, kMax] <- NA_real_
+                    results$conditionalPower[population, kMax] <- NA_real_
                 } else {
-                    results$conditionalPower[g, kMax] <- 1 - stats::pnorm(.getQNorm(result) -
-                        standardizedEffect[g] * sqrt(nPlanned[kMax]))
+                    results$conditionalPower[population, kMax] <- 1 - stats::pnorm(.getQNorm(result) -
+                        standardizedEffect[population] * sqrt(nPlanned[kMax]))
                 }
             }
         }
@@ -1016,9 +1025,11 @@
     return(results)
 }
 
-#
-# Calculation of conditional power and likelihood values for plotting the graph
-#
+#'
+#' Calculation of conditional power and likelihood values for plotting the graph
+#'
+#' @noRd
+#'
 .getConditionalPowerLikelihoodSurvivalEnrichment <- function(..., stageResults, stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaRange, iterations = C_ITERATIONS_DEFAULT, seed = NA_real_) {
@@ -1056,8 +1067,8 @@
 
     j <- 1
     for (i in seq(along = thetaRange)) {
-        for (g in (1:gMax)) {
-            populations[j] <- g
+        for (population in (1:gMax)) {
+            populations[j] <- population
             effectValues[j] <- thetaRange[i]
 
             if (.isTrialDesignInverseNormal(design)) {
@@ -1066,7 +1077,7 @@
                     design = design, stageResults = stageResults, stage = stage, nPlanned = nPlanned,
                     allocationRatioPlanned = allocationRatioPlanned,
                     thetaH1 = thetaRange[i], ...
-                )$conditionalPower[g, kMax]
+                )$conditionalPower[population, kMax]
             } else if (.isTrialDesignFisher(design)) {
                 condPowerValues[j] <- .getConditionalPowerSurvivalEnrichmentFisher(
                     results = results,
@@ -1074,12 +1085,12 @@
                     allocationRatioPlanned = allocationRatioPlanned,
                     thetaH1 = thetaRange[i],
                     iterations = iterations, seed = seed, ...
-                )$conditionalPower[g, kMax]
+                )$conditionalPower[population, kMax]
             }
             likelihoodValues[j] <- stats::dnorm(
-                log(thetaRange[i]), log(stageResults$effectSizes[g, stage]),
-                stdErr[g]
-            ) / stats::dnorm(0, 0, stdErr[g])
+                log(thetaRange[i]), log(stageResults$effectSizes[population, stage]),
+                stdErr[population]
+            ) / stats::dnorm(0, 0, stdErr[population])
             j <- j + 1
         }
     }
