@@ -13,11 +13,14 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5684 $
-## |  Last changed: $Date: 2022-01-05 12:27:24 +0100 (Mi, 05 Jan 2022) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 7126 $
+## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  Last changed by: $Author: pahlke $
 ## |
 
+#' @include f_logger.R
+NULL
+
 .getAnalysisResultsMeansMultiArm <- function(..., design, dataInput) {
     if (.isTrialDesignInverseNormal(design)) {
         return(.getAnalysisResultsMeansInverseNormalMultiArm(design = design, dataInput = dataInput, ...))
@@ -210,37 +213,26 @@
     results$.setParameterType("iterations", C_PARAM_NOT_APPLICABLE)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
-            conditionalPowerResults <- .getConditionalPowerMeansMultiArm(
+            results$.conditionalPowerResults <- .getConditionalPowerMeansMultiArm(
                 stageResults = stageResults,
                 stage = stage, nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 thetaH1 = thetaH1, assumedStDevs = assumedStDevs, iterations = iterations, seed = seed
             )
-            if (conditionalPowerResults$simulated) {
-                results$conditionalPowerSimulated <- conditionalPowerResults$conditionalPower
-                results$.setParameterType("conditionalPower", C_PARAM_NOT_APPLICABLE)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_GENERATED)
-            } else {
-                results$conditionalPower <- conditionalPowerResults$conditionalPower
-                results$conditionalPowerSimulated <- matrix(numeric(0))
-                results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_NOT_APPLICABLE)
-            }
+            .synchronizeIterationsAndSeed(results)
         } else {
-            conditionalPowerResults <- .getConditionalPowerMeansMultiArm(
+            results$.conditionalPowerResults <- .getConditionalPowerMeansMultiArm(
                 stageResults = stageResults,
                 stage = stage, nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 thetaH1 = thetaH1, assumedStDevs = assumedStDevs
             )
-            results$conditionalPower <- conditionalPowerResults$conditionalPower
+            results$conditionalPower <- results$.conditionalPowerResults$conditionalPower
             results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
         }
-        results$thetaH1 <- matrix(conditionalPowerResults$thetaH1, ncol = 1)
-        results$assumedStDevs <- matrix(conditionalPowerResults$assumedStDevs, ncol = 1)
-        results$.conditionalPowerResults <- conditionalPowerResults
+        results$thetaH1 <- matrix(results$.conditionalPowerResults$thetaH1, ncol = 1)
+        results$assumedStDevs <- matrix(results$.conditionalPowerResults$assumedStDevs, ncol = 1)
         .logProgress("Conditional power calculated", startTime = startTime)
 
         # CRP - conditional rejection probabilities
@@ -470,8 +462,8 @@
             if (!directionUpper) {
                 separatePValues[treatmentArm, k] <- 1 - separatePValues[treatmentArm, k]
                 overallPValues[treatmentArm, k] <- 1 - overallPValues[treatmentArm, k]
-                # testStatistics[g, k] <- -testStatistics[g, k]
-                # overallTestStatistics[g, k] <- -overallTestStatistics[g, k]
+                # testStatistics[treatmentArm, k] <- -testStatistics[treatmentArm, k]
+                # overallTestStatistics[treatmentArm, k] <- -overallTestStatistics[treatmentArm, k]
             }
         }
     }
@@ -751,7 +743,6 @@
         }
         .logProgress("Confidence intervals for final stage calculated", startTime = startTime)
     } else {
-
         # Repeated onfidence intervals when using combination tests
         if (intersectionTest == "Hierarchical") {
             warning("Repeated confidence intervals not available for ",
@@ -782,8 +773,7 @@
         for (k in stages) {
             startTime <- Sys.time()
             for (treatmentArm in 1:gMax) {
-                if (!is.na(stageResults$testStatistics[treatmentArm, k])) {
-
+                if (!is.na(stageResults$testStatistics[treatmentArm, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
                     # finding maximum upper and minimum lower bounds for RCIs
                     thetaLow <- .getUpperLowerThetaMeansMultiArm(
                         design = design, dataInput = dataInput,
@@ -823,7 +813,7 @@
                     )
 
                     # adjustment for binding futility bounds
-                    if (k > 1 && conditionFunction(bounds[k - 1], border) & design$bindingFutility) {
+                    if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
                         parameterName <- ifelse(.isTrialDesignFisher(design),
                             "singleStepAdjustedPValues", firstParameterName
                         )
@@ -888,9 +878,11 @@
     return(repeatedConfidenceIntervals)
 }
 
-#
-# RCIs based on inverse normal combination test
-#
+#'
+#' RCIs based on inverse normal combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMeansMultiArmInverseNormal <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_MEANS_DEFAULT,
@@ -912,9 +904,11 @@
     ))
 }
 
-#
-# RCIs based on Fisher's combination test
-#
+#'
+#' RCIs based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMeansMultiArmFisher <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_MEANS_DEFAULT,
@@ -936,9 +930,11 @@
     ))
 }
 
-#
-# CIs based on conditional Dunnett test
-#
+#'
+#' CIs based on conditional Dunnett test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMeansMultiArmConditionalDunnett <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_MEANS_DEFAULT,
@@ -963,9 +959,11 @@
     ))
 }
 
-#
-#  Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Means
-#
+#'
+#' Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Means
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMeansMultiArm <- function(..., design) {
     if (.isTrialDesignInverseNormal(design)) {
         return(.getRepeatedConfidenceIntervalsMeansMultiArmInverseNormal(design = design, ...))
@@ -979,9 +977,11 @@
     .stopWithWrongDesignMessage(design)
 }
 
-#
-#  Calculation of conditional power for Means
-#
+#'
+#' Calculation of conditional power for Means
+#'
+#' @noRd
+#'
 .getConditionalPowerMeansMultiArm <- function(..., stageResults, stage = stageResults$stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaH1 = NA_real_, assumedStDevs = NA_real_,
@@ -1035,9 +1035,9 @@
         assumedStDevs, stageResults, stage,
         results = results
     )
+    .assertIsValidAssumedStDevs(assumedStDevs, gMax)
     thetaH1 <- .assertIsValidThetaH1ForMultiArm(thetaH1, stageResults, stage, results = results)
     results$.setParameterType("nPlanned", C_PARAM_USER_DEFINED)
-
     if (length(thetaH1) != 1 && length(thetaH1) != gMax) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
@@ -1047,15 +1047,6 @@
             ), .arrayToString(thetaH1), gMax)
         )
     }
-    if (length(assumedStDevs) != 1 && length(assumedStDevs) != gMax) {
-        stop(
-            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-            sprintf(paste0(
-                "length of 'assumedStDevs' (%s) ",
-                "must be equal to 'gMax' (%s) or 1"
-            ), .arrayToString(assumedStDevs), gMax)
-        )
-    }
 
     if (length(assumedStDevs) == 1) {
         results$assumedStDevs <- rep(assumedStDevs, gMax)
@@ -1096,9 +1087,11 @@
     )
 }
 
-#
-# Calculation of conditional power based on inverse normal method
-#
+#'
+#' Calculation of conditional power based on inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalPowerMeansMultiArmInverseNormal <- function(..., results, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1, assumedStDevs) {
     design <- stageResults$.design
@@ -1187,9 +1180,11 @@
     return(results)
 }
 
-#
-# Calculation of conditional power based on Fisher's combination test
-#
+#'
+#' Calculation of conditional power based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getConditionalPowerMeansMultiArmFisher <- function(..., results, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1, assumedStDevs,
         iterations, seed) {
@@ -1291,9 +1286,11 @@
     return(results)
 }
 
-#
-# Calculation of conditional power based on conditional Dunnett test
-#
+#'
+#' Calculation of conditional power based on conditional Dunnett test
+#'
+#' @noRd
+#'
 .getConditionalPowerMeansMultiArmConditionalDunnett <- function(..., results, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1, assumedStDevs) {
     design <- stageResults$.design
@@ -1348,9 +1345,11 @@
     return(results)
 }
 
-#
-# Calculation of conditional power and likelihood values for plotting the graph
-#
+#'
+#' Calculation of conditional power and likelihood values for plotting the graph
+#'
+#' @noRd
+#'
 .getConditionalPowerLikelihoodMeansMultiArm <- function(..., stageResults, stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaRange, assumedStDevs = NA_real_,
