@@ -13,23 +13,29 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5684 $
-## |  Last changed: $Date: 2022-01-05 12:27:24 +0100 (Mi, 05 Jan 2022) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 7126 $
+## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  Last changed by: $Author: pahlke $
 ## |
 
-# @title
-# Get Analysis Results Rates
-#
-# @description
-# Returns an analysis result object.
-#
-# @param design The trial design.
-#
-# @return Returns a \code{AnalysisResultsRates} object.
-#
-# @keywords internal
-#
+#' @include f_logger.R
+NULL
+
+#'
+#' @title
+#' Get Analysis Results Rates
+#'
+#' @description
+#' Returns an analysis result object.
+#'
+#' @param design The trial design.
+#'
+#' @return Returns a \code{AnalysisResultsRates} object.
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
 .getAnalysisResultsRatesMultiArm <- function(..., design, dataInput) {
     if (.isTrialDesignInverseNormal(design)) {
         return(.getAnalysisResultsRatesInverseNormalMultiArm(
@@ -217,35 +223,24 @@
     .logProgress("Closed test calculated", startTime = startTime)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
-            conditionalPowerResults <- .getConditionalPowerRatesMultiArm(
+            results$.conditionalPowerResults <- .getConditionalPowerRatesMultiArm(
                 stageResults = stageResults,
                 stage = stage, nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 piTreatments = piTreatments, piControl = piControl, iterations = iterations, seed = seed
             )
-            if (conditionalPowerResults$simulated) {
-                results$conditionalPowerSimulated <- conditionalPowerResults$conditionalPower
-                results$.setParameterType("conditionalPower", C_PARAM_NOT_APPLICABLE)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_GENERATED)
-            } else {
-                results$conditionalPower <- conditionalPowerResults$conditionalPower
-                results$conditionalPowerSimulated <- matrix(numeric(0))
-                results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_NOT_APPLICABLE)
-            }
+            .synchronizeIterationsAndSeed(results)
         } else {
-            conditionalPowerResults <- .getConditionalPowerRatesMultiArm(
+            results$.conditionalPowerResults <- .getConditionalPowerRatesMultiArm(
                 stageResults = stageResults,
                 stage = stage, nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 piTreatments = piTreatments, piControl = piControl
             )
-            results$conditionalPower <- conditionalPowerResults$conditionalPower
+            results$conditionalPower <- results$.conditionalPowerResults$conditionalPower
             results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
         }
-        results$.conditionalPowerResults <- conditionalPowerResults
         .logProgress("Conditional power calculated", startTime = startTime)
 
         # CRP - conditional rejection probabilities
@@ -362,13 +357,13 @@
         piControl[1, k] <- dataInput$getOverallEvents(stage = k, group = gMax + 1) /
             dataInput$getOverallSampleSizes(stage = k, group = gMax + 1)
 
-        for (g in 1:gMax) {
-            piTreatments[g, k] <- dataInput$getOverallEvents(stage = k, group = g) /
-                dataInput$getOverallSampleSizes(stage = k, group = g)
+        for (treatmentArm in 1:gMax) {
+            piTreatments[treatmentArm, k] <- dataInput$getOverallEvents(stage = k, group = treatmentArm) /
+                dataInput$getOverallSampleSizes(stage = k, group = treatmentArm)
 
-            actEv <- dataInput$getEvents(stage = k, group = g)
+            actEv <- dataInput$getEvents(stage = k, group = treatmentArm)
             ctrEv <- dataInput$getEvents(stage = k, group = gMax + 1)
-            actN <- dataInput$getSampleSize(stage = k, group = g)
+            actN <- dataInput$getSampleSize(stage = k, group = treatmentArm)
             ctrN <- dataInput$getSampleSize(stage = k, group = gMax + 1)
 
             if (normalApproximation) {
@@ -376,10 +371,10 @@
                     if (!is.na(actEv)) {
                         if ((actEv + ctrEv == 0) ||
                                 (actEv + ctrEv == actN + ctrN)) {
-                            testStatistics[g, k] <- 0
+                            testStatistics[treatmentArm, k] <- 0
                         } else {
                             rateH0 <- (actEv + ctrEv) / (actN + ctrN)
-                            testStatistics[g, k] <- (actEv / actN - ctrEv / ctrN - thetaH0) /
+                            testStatistics[treatmentArm, k] <- (actEv / actN - ctrEv / ctrN - thetaH0) /
                                 sqrt(rateH0 * (1 - rateH0) * (1 / actN + 1 / ctrN))
                         }
                     }
@@ -389,15 +384,15 @@
                         rate2 = ctrEv / ctrN, theta = thetaH0, allocation = actN / ctrN, method = "diff"
                     )
 
-                    testStatistics[g, k] <-
+                    testStatistics[treatmentArm, k] <-
                         (actEv / actN - ctrEv / ctrN - thetaH0) /
                             sqrt(y$ml1 * (1 - y$ml1) / actN + y$ml2 * (1 - y$ml2) / ctrN)
                 }
 
                 if (directionUpper) {
-                    separatePValues[g, k] <- 1 - stats::pnorm(testStatistics[g, k])
+                    separatePValues[treatmentArm, k] <- 1 - stats::pnorm(testStatistics[treatmentArm, k])
                 } else {
-                    separatePValues[g, k] <- stats::pnorm(testStatistics[g, k])
+                    separatePValues[treatmentArm, k] <- stats::pnorm(testStatistics[treatmentArm, k])
                 }
             } else {
                 if (thetaH0 != 0) {
@@ -408,14 +403,14 @@
                 }
 
                 if (directionUpper) {
-                    separatePValues[g, k] <- stats::phyper(actEv - 1,
+                    separatePValues[treatmentArm, k] <- stats::phyper(actEv - 1,
                         actEv + ctrEv,
                         actN + ctrN - actEv - ctrEv,
                         actN,
                         lower.tail = FALSE
                     )
                 } else {
-                    separatePValues[g, k] <- stats::phyper(actEv,
+                    separatePValues[treatmentArm, k] <- stats::phyper(actEv,
                         actEv + ctrEv,
                         actN + ctrN - actEv - ctrEv,
                         actN,
@@ -430,9 +425,9 @@
             }
 
             # overall test statistics
-            actEv <- dataInput$getOverallEvents(stage = k, group = g)
+            actEv <- dataInput$getOverallEvents(stage = k, group = treatmentArm)
             ctrEv <- dataInput$getOverallEvents(stage = k, group = gMax + 1)
-            actN <- dataInput$getOverallSampleSize(stage = k, group = g)
+            actN <- dataInput$getOverallSampleSize(stage = k, group = treatmentArm)
             ctrN <- dataInput$getOverallSampleSize(stage = k, group = gMax + 1)
 
             if (normalApproximation) {
@@ -440,10 +435,10 @@
                     if (!is.na(actEv)) {
                         if ((actEv + ctrEv == 0) ||
                                 (actEv + ctrEv == actN + ctrN)) {
-                            overallTestStatistics[g, k] <- 0
+                            overallTestStatistics[treatmentArm, k] <- 0
                         } else {
                             overallRateH0 <- (actEv + ctrEv) / (actN + ctrN)
-                            overallTestStatistics[g, k] <- (actEv / actN - ctrEv / ctrN - thetaH0) /
+                            overallTestStatistics[treatmentArm, k] <- (actEv / actN - ctrEv / ctrN - thetaH0) /
                                 sqrt(overallRateH0 * (1 - overallRateH0) * (1 / actN + 1 / ctrN))
                         }
                     }
@@ -453,15 +448,15 @@
                         theta = thetaH0, allocation = actN / ctrN, method = "diff"
                     )
 
-                    overallTestStatistics[g, k] <-
+                    overallTestStatistics[treatmentArm, k] <-
                         (actEv / actN - ctrEv / ctrN - thetaH0) /
                             sqrt(y$ml1 * (1 - y$ml1) / actN + y$ml2 * (1 - y$ml2) / ctrN)
                 }
 
                 if (directionUpper) {
-                    overallPValues[g, k] <- 1 - stats::pnorm(overallTestStatistics[g, k])
+                    overallPValues[treatmentArm, k] <- 1 - stats::pnorm(overallTestStatistics[treatmentArm, k])
                 } else {
-                    overallPValues[g, k] <- stats::pnorm(overallTestStatistics[g, k])
+                    overallPValues[treatmentArm, k] <- stats::pnorm(overallTestStatistics[treatmentArm, k])
                 }
             } else {
                 if (thetaH0 != 0) {
@@ -472,14 +467,14 @@
                 }
 
                 if (directionUpper) {
-                    overallPValues[g, k] <- stats::phyper(actEv - 1,
+                    overallPValues[treatmentArm, k] <- stats::phyper(actEv - 1,
                         actEv + ctrEv,
                         actN + ctrN - actEv - ctrEv,
                         actN,
                         lower.tail = FALSE
                     )
                 } else {
-                    overallPValues[g, k] <- stats::phyper(actEv,
+                    overallPValues[treatmentArm, k] <- stats::phyper(actEv,
                         actEv + ctrEv,
                         actN + ctrN - actEv - ctrEv,
                         actN,
@@ -504,8 +499,8 @@
     stageResults$separatePValues <- separatePValues
 
     effectSizes <- matrix(numeric(0), ncol = ncol(piControl))
-    for (g in 1:gMax) {
-        effectSizes <- rbind(effectSizes, piTreatments[g, ] - piControl)
+    for (treatmentArm in 1:gMax) {
+        effectSizes <- rbind(effectSizes, piTreatments[treatmentArm, ] - piControl)
     }
     stageResults$effectSizes <- effectSizes
     stageResults$.setParameterType("effectSizes", C_PARAM_GENERATED)
@@ -538,35 +533,35 @@
             sqrt(t(sampleSizesSelected / (sampleSizesSelected +
                 dataInput$getSampleSize(k, gMax + 1))))
         diag(sigma) <- 1
-        for (g in 1:gMax) {
+        for (treatmentArm in 1:gMax) {
             if ((intersectionTest == "Bonferroni") || (intersectionTest == "Simes")) {
                 if (.isTrialDesignGroupSequential(design)) {
-                    overallPValues[g, k] <- min(1, overallPValues[g, k] * selected)
+                    overallPValues[treatmentArm, k] <- min(1, overallPValues[treatmentArm, k] * selected)
                 } else {
-                    singleStepAdjustedPValues[g, k] <- min(1, separatePValues[g, k] * selected)
+                    singleStepAdjustedPValues[treatmentArm, k] <- min(1, separatePValues[treatmentArm, k] * selected)
                 }
             } else if (intersectionTest == "Sidak") {
                 if (.isTrialDesignGroupSequential(design)) {
-                    overallPValues[g, k] <- 1 - (1 - overallPValues[g, k])^selected
+                    overallPValues[treatmentArm, k] <- 1 - (1 - overallPValues[treatmentArm, k])^selected
                 } else {
-                    singleStepAdjustedPValues[g, k] <- 1 - (1 - separatePValues[g, k])^selected
+                    singleStepAdjustedPValues[treatmentArm, k] <- 1 - (1 - separatePValues[treatmentArm, k])^selected
                 }
             } else if (intersectionTest == "Dunnett") {
-                if (!is.na(testStatistics[g, k])) {
+                if (!is.na(testStatistics[treatmentArm, k])) {
                     df <- NA_real_
-                    singleStepAdjustedPValues[g, k] <- 1 - .getMultivariateDistribution(
+                    singleStepAdjustedPValues[treatmentArm, k] <- 1 - .getMultivariateDistribution(
                         type = "normal",
-                        upper = ifelse(directionUpper, testStatistics[g, k], -testStatistics[g, k]),
+                        upper = ifelse(directionUpper, testStatistics[treatmentArm, k], -testStatistics[treatmentArm, k]),
                         sigma = sigma, df = df
                     )
                 }
             }
             if (.isTrialDesignInverseNormal(design)) {
-                combInverseNormal[g, k] <- (weightsInverseNormal[1:k] %*%
-                    .getOneMinusQNorm(singleStepAdjustedPValues[g, 1:k])) /
+                combInverseNormal[treatmentArm, k] <- (weightsInverseNormal[1:k] %*%
+                    .getOneMinusQNorm(singleStepAdjustedPValues[treatmentArm, 1:k])) /
                     sqrt(sum(weightsInverseNormal[1:k]^2))
             } else if (.isTrialDesignFisher(design)) {
-                combFisher[g, k] <- prod(singleStepAdjustedPValues[g, 1:k]^weightsFisher[1:k])
+                combFisher[treatmentArm, k] <- prod(singleStepAdjustedPValues[treatmentArm, 1:k]^weightsFisher[1:k])
             }
         }
     }
@@ -609,7 +604,6 @@
     return(result)
 }
 
-
 .getRepeatedConfidenceIntervalsRatesMultiArmAll <- function(...,
         design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
@@ -718,23 +712,23 @@
         stages <- (1:stage)
         for (k in stages) {
             startTime <- Sys.time()
-            for (g in 1:gMax) {
-                if (!is.na(stageResults$testStatistics[g, k])) {
+            for (treatmentArm in 1:gMax) {
+                if (!is.na(stageResults$testStatistics[treatmentArm, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
                     thetaLow <- -1 + tolerance
                     thetaUp <- 1 - tolerance
                     # finding upper and lower RCI limits through root function
-                    repeatedConfidenceIntervals[g, 1, k] <- .getRootThetaRatesMultiArm(
+                    repeatedConfidenceIntervals[treatmentArm, 1, k] <- .getRootThetaRatesMultiArm(
                         design = design,
-                        dataInput = dataInput, treatmentArm = g, stage = k, directionUpper = TRUE,
+                        dataInput = dataInput, treatmentArm = treatmentArm, stage = k, directionUpper = TRUE,
                         normalApproximation = normalApproximation,
                         thetaLow = thetaLow, thetaUp = thetaUp,
                         intersectionTest = intersectionTest, firstParameterName = firstParameterName,
                         secondValue = criticalValues[k], tolerance = tolerance
                     )
 
-                    repeatedConfidenceIntervals[g, 2, k] <- .getRootThetaRatesMultiArm(
+                    repeatedConfidenceIntervals[treatmentArm, 2, k] <- .getRootThetaRatesMultiArm(
                         design = design,
-                        dataInput = dataInput, treatmentArm = g, stage = k, directionUpper = FALSE,
+                        dataInput = dataInput, treatmentArm = treatmentArm, stage = k, directionUpper = FALSE,
                         normalApproximation = normalApproximation,
                         thetaLow = thetaLow, thetaUp = thetaUp,
                         intersectionTest = intersectionTest, firstParameterName = firstParameterName,
@@ -742,14 +736,14 @@
                     )
 
                     # adjustment for binding futility bounds
-                    if (k > 1 && conditionFunction(bounds[k - 1], border) & design$bindingFutility) {
+                    if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
                         parameterName <- ifelse(.isTrialDesignFisher(design),
                             "singleStepAdjustedPValues", firstParameterName
                         )
 
                         futilityCorr[k] <- .getRootThetaRatesMultiArm(
                             design = design, dataInput = dataInput,
-                            treatmentArm = g, stage = k - 1, directionUpper = directionUpper,
+                            treatmentArm = treatmentArm, stage = k - 1, directionUpper = directionUpper,
                             normalApproximation = normalApproximation,
                             thetaLow = thetaLow, thetaUp = thetaUp,
                             intersectionTest = intersectionTest, firstParameterName = parameterName,
@@ -757,22 +751,22 @@
                         )
 
                         if (directionUpper) {
-                            repeatedConfidenceIntervals[g, 1, k] <- min(
+                            repeatedConfidenceIntervals[treatmentArm, 1, k] <- min(
                                 min(futilityCorr[2:k]),
-                                repeatedConfidenceIntervals[g, 1, k]
+                                repeatedConfidenceIntervals[treatmentArm, 1, k]
                             )
                         } else {
-                            repeatedConfidenceIntervals[g, 2, k] <- max(
+                            repeatedConfidenceIntervals[treatmentArm, 2, k] <- max(
                                 max(futilityCorr[2:k]),
-                                repeatedConfidenceIntervals[g, 2, k]
+                                repeatedConfidenceIntervals[treatmentArm, 2, k]
                             )
                         }
                     }
 
-                    if (!is.na(repeatedConfidenceIntervals[g, 1, k]) &&
-                            !is.na(repeatedConfidenceIntervals[g, 2, k]) &&
-                            repeatedConfidenceIntervals[g, 1, k] > repeatedConfidenceIntervals[g, 2, k]) {
-                        repeatedConfidenceIntervals[g, , k] <- rep(NA_real_, 2)
+                    if (!is.na(repeatedConfidenceIntervals[treatmentArm, 1, k]) &&
+                            !is.na(repeatedConfidenceIntervals[treatmentArm, 2, k]) &&
+                            repeatedConfidenceIntervals[treatmentArm, 1, k] > repeatedConfidenceIntervals[treatmentArm, 2, k]) {
+                        repeatedConfidenceIntervals[treatmentArm, , k] <- rep(NA_real_, 2)
                     }
                 }
             }
@@ -783,9 +777,11 @@
     return(repeatedConfidenceIntervals)
 }
 
-#
-# RCIs based on inverse normal combination test
-#
+#'
+#' RCIs based on inverse normal combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesMultiArmInverseNormal <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -811,9 +807,11 @@
     ))
 }
 
-#
-# RCIs based on Fisher's combination test
-#
+#'
+#' RCIs based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesMultiArmFisher <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -842,9 +840,11 @@
     ))
 }
 
-#
-# CIs based on conditional Dunnett test
-#
+#'
+#' CIs based on conditional Dunnett test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesMultiArmConditionalDunnett <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -865,9 +865,11 @@
     ))
 }
 
-#
-#  Calculation of repeated confidence intervals (RCIs) for Rates
-#
+#'
+#' Calculation of repeated confidence intervals (RCIs) for Rates
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesMultiArm <- function(..., design) {
     if (.isTrialDesignInverseNormal(design)) {
         return(.getRepeatedConfidenceIntervalsRatesMultiArmInverseNormal(design = design, ...))
@@ -881,9 +883,11 @@
     .stopWithWrongDesignMessage(design)
 }
 
-#
-#  Calculation of conditional power for Rates
-#
+#'
+#' Calculation of conditional power for Rates
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesMultiArm <- function(..., stageResults, stage = stageResults$stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         piTreatments = NA_real_, piControl = NA_real_, useAdjustment = TRUE,
@@ -1005,9 +1009,11 @@
     )
 }
 
-#
-# Calculation of conditional power based on inverse normal method
-#
+#'
+#' Calculation of conditional power based on inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesMultiArmInverseNormal <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, piTreatments, piControl) {
     .assertIsTrialDesignInverseNormal(design)
@@ -1051,16 +1057,16 @@
     ctr <- .performClosedCombinationTest(stageResults = stageResults)
     criticalValues <- design$criticalValues
 
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
+    for (treatmentArm in 1:gMax) {
+        if (!is.na(ctr$separatePValues[treatmentArm, stage])) {
             # shifted decision region for use in getGroupSeqProbs
             # Inverse Normal Method
             shiftedDecisionRegionUpper <- criticalValues[(stage + 1):kMax] *
                 sqrt(sum(weights[1:stage]^2) + cumsum(weights[(stage + 1):kMax]^2)) /
                 sqrt(cumsum(weights[(stage + 1):kMax]^2)) -
-                min(ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage], na.rm = TRUE) *
+                min(ctr$overallAdjustedTestStatistics[ctr$indices[, treatmentArm] == 1, stage], na.rm = TRUE) *
                     sqrt(sum(weights[1:stage]^2)) /
-                    sqrt(cumsum(weights[(stage + 1):kMax]^2)) - standardizedEffect[g] *
+                    sqrt(cumsum(weights[(stage + 1):kMax]^2)) - standardizedEffect[treatmentArm] *
                     cumsum(sqrt(nPlanned[(stage + 1):kMax]) * weights[(stage + 1):kMax]) /
                     sqrt(cumsum(weights[(stage + 1):kMax]^2))
             if (stage == kMax - 1) {
@@ -1069,9 +1075,9 @@
                 shiftedFutilityBounds <- design$futilityBounds[(stage + 1):(kMax - 1)] *
                     sqrt(sum(weights[1:stage]^2) + cumsum(weights[(stage + 1):(kMax - 1)]^2)) /
                     sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) -
-                    min(ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage], na.rm = TRUE) *
+                    min(ctr$overallAdjustedTestStatistics[ctr$indices[, treatmentArm] == 1, stage], na.rm = TRUE) *
                         sqrt(sum(weights[1:stage]^2)) /
-                        sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) - standardizedEffect[g] *
+                        sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) - standardizedEffect[treatmentArm] *
                         cumsum(sqrt(nPlanned[(stage + 1):(kMax - 1)]) * weights[(stage + 1):(kMax - 1)]) /
                         sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2))
             }
@@ -1090,7 +1096,7 @@
                 informationRates = scaledInformation
             )
 
-            results$conditionalPower[g, (stage + 1):kMax] <- cumsum(probs[3, ] - probs[2, ])
+            results$conditionalPower[treatmentArm, (stage + 1):kMax] <- cumsum(probs[3, ] - probs[2, ])
         }
     }
     nPlanned <- (1 + allocationRatioPlanned)^2 / allocationRatioPlanned * nPlanned
@@ -1104,9 +1110,11 @@
     return(results)
 }
 
-#
-# Calculation of conditional power based on Fisher's combination test
-#
+#'
+#' Calculation of conditional power based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesMultiArmFisher <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, piTreatments, piControl, useAdjustment = TRUE,
         iterations, seed) {
@@ -1164,13 +1172,13 @@
     nPlanned <- allocationRatioPlanned / (1 + allocationRatioPlanned)^2 * nPlanned
 
     ctr <- .performClosedCombinationTest(stageResults = stageResults)
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
+    for (treatmentArm in 1:gMax) {
+        if (!is.na(ctr$separatePValues[treatmentArm, stage])) {
             if (gMax == 1) {
-                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, g] == 1, ][1:stage]
+                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, treatmentArm] == 1, ][1:stage]
             } else {
-                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, g] == 1, ][which.max(
-                    ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage]
+                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, treatmentArm] == 1, ][which.max(
+                    ctr$overallAdjustedTestStatistics[ctr$indices[, treatmentArm] == 1, stage]
                 ), 1:stage]
             }
             if (stage < kMax - 1) {
@@ -1180,11 +1188,11 @@
                         reject <- reject + .getRejectValueConditionalPowerFisher(
                             kMax = kMax, alpha0Vec = design$alpha0Vec,
                             criticalValues = criticalValues, weightsFisher = weightsFisher,
-                            pValues = pValues, currentKMax = k, thetaH1 = standardizedEffect[g],
+                            pValues = pValues, currentKMax = k, thetaH1 = standardizedEffect[treatmentArm],
                             stage = stage, nPlanned = nPlanned
                         )
                     }
-                    results$conditionalPower[g, k] <- reject / iterations
+                    results$conditionalPower[treatmentArm, k] <- reject / iterations
                 }
                 results$simulated <- TRUE
                 results$.setParameterType("simulated", C_PARAM_GENERATED)
@@ -1194,10 +1202,10 @@
 
                 if (result <= 0 || result >= 1) {
                     warning("Calculation not possible: could not calculate conditional power for stage ", kMax, call. = FALSE)
-                    results$conditionalPower[g, kMax] <- NA_real_
+                    results$conditionalPower[treatmentArm, kMax] <- NA_real_
                 } else {
-                    results$conditionalPower[g, kMax] <- 1 - stats::pnorm(.getQNorm(result) -
-                        standardizedEffect[g] * sqrt(nPlanned[kMax]))
+                    results$conditionalPower[treatmentArm, kMax] <- 1 - stats::pnorm(.getQNorm(result) -
+                        standardizedEffect[treatmentArm] * sqrt(nPlanned[kMax]))
                 }
             }
         }
@@ -1222,9 +1230,11 @@
     return(results)
 }
 
-#
-# Calculation of conditional power based on conditional Dunnett test
-#
+#'
+#' Calculation of conditional power based on conditional Dunnett test
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesMultiArmConditionalDunnett <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, piTreatments, piControl) {
     .assertIsTrialDesignConditionalDunnett(design)
@@ -1264,13 +1274,13 @@
 
     ctr <- .getClosedConditionalDunnettTestResults(stageResults = stageResults, design = design, stage = stage)
 
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
-            results$conditionalPower[g, 2] <- 1 -
+    for (treatmentArm in 1:gMax) {
+        if (!is.na(ctr$separatePValues[treatmentArm, stage])) {
+            results$conditionalPower[treatmentArm, 2] <- 1 -
                 stats::pnorm(.getOneMinusQNorm(min(ctr$conditionalErrorRate[
-                    ctr$indices[, g] == 1,
+                    ctr$indices[, treatmentArm] == 1,
                     stage
-                ], na.rm = TRUE)) - standardizedEffect[g] * sqrt(nPlanned[2]))
+                ], na.rm = TRUE)) - standardizedEffect[treatmentArm] * sqrt(nPlanned[2]))
         }
     }
 
@@ -1285,9 +1295,11 @@
     return(results)
 }
 
-#
-# Calculation of conditional power and likelihood values for plotting the graph
-#
+#'
+#' Calculation of conditional power and likelihood values for plotting the graph
+#'
+#' @noRd
+#'
 .getConditionalPowerLikelihoodRatesMultiArm <- function(..., stageResults, stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         piTreatmentRange, piControl = NA_real_,
@@ -1329,8 +1341,8 @@
 
     j <- 1
     for (i in seq(along = piTreatmentRange)) {
-        for (g in (1:gMax)) {
-            treatmentArms[j] <- g
+        for (treatmentArm in (1:gMax)) {
+            treatmentArms[j] <- treatmentArm
             effectValues[j] <- piTreatmentRange[i]
 
             if (.isTrialDesignInverseNormal(design)) {
@@ -1340,7 +1352,7 @@
                     allocationRatioPlanned = allocationRatioPlanned,
                     piControl = piControl,
                     piTreatments = piTreatmentRange[i]
-                )$conditionalPower[g, kMax]
+                )$conditionalPower[treatmentArm, kMax]
             } else if (.isTrialDesignFisher(design)) {
                 condPowerValues[j] <- .getConditionalPowerRatesMultiArmFisher(
                     results = results,
@@ -1349,7 +1361,7 @@
                     piControl = piControl,
                     piTreatments = piTreatmentRange[i],
                     iterations = iterations, seed = seed
-                )$conditionalPower[g, kMax]
+                )$conditionalPower[treatmentArm, kMax]
             } else if (.isTrialDesignConditionalDunnett(design)) {
                 condPowerValues[j] <- .getConditionalPowerRatesMultiArmConditionalDunnett(
                     results = results,
@@ -1357,11 +1369,11 @@
                     allocationRatioPlanned = allocationRatioPlanned,
                     piControl = piControl,
                     piTreatments = piTreatmentRange[i]
-                )$conditionalPower[g, 2]
+                )$conditionalPower[treatmentArm, 2]
             }
 
-            likelihoodValues[j] <- stats::dnorm(piTreatmentRange[i], stageResults$overallPiTreatments[g, stage], stdErr[g]) /
-                stats::dnorm(0, 0, stdErr[g])
+            likelihoodValues[j] <- stats::dnorm(piTreatmentRange[i], stageResults$overallPiTreatments[treatmentArm, stage], stdErr[treatmentArm]) /
+                stats::dnorm(0, 0, stdErr[treatmentArm])
             j <- j + 1
         }
     }
