@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6656 $
-## |  Last changed: $Date: 2022-11-03 08:41:40 +0100 (Thu, 03 Nov 2022) $
+## |  File version: $Revision: 7126 $
+## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -461,6 +461,7 @@ testPackage <- function(outDir = ".", ...,
     .assertTestthatIsInstalled()
     .assertMnormtIsInstalled()
 
+    .assertIsSingleCharacter(outDir, "outDir", naAllowed = FALSE)
     if (!dir.exists(outDir)) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
@@ -624,6 +625,7 @@ testPackage <- function(outDir = ".", ...,
 }
 
 .testInstalledPackage <- function(testFileDirectory, ..., pkgName = "rpact", outDir = ".", Ropts = "") {
+    .assertIsSingleCharacter(testFileDirectory, "testFileDirectory", naAllowed = FALSE)
     if (!dir.exists(testFileDirectory)) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'testFileDirectory' (", testFileDirectory, ") does not exist")
     }
@@ -651,11 +653,12 @@ testPackage <- function(outDir = ".", ...,
 
         savefile <- paste(outfile, "save", sep = ".")
         if (file.exists(savefile)) {
-            message(gettextf(
-                "  comparing %s to %s ...",
-                sQuote(outfile), sQuote(savefile)
-            ),
-            appendLF = FALSE, domain = NA
+            message(
+                gettextf(
+                    "  comparing %s to %s ...",
+                    sQuote(outfile), sQuote(savefile)
+                ),
+                appendLF = FALSE, domain = NA
             )
             res <- Rdiff(outfile, savefile)
             if (!res) message(" OK")
@@ -675,20 +678,20 @@ testPackage <- function(outDir = ".", ...,
     return(isTRUE(completeUnitTestSetEnabled))
 }
 
-#' 
-#' @title 
+#'
+#' @title
 #' Test Plan Section
-#' 
+#'
 #' @param section The section title or description.
-#' 
-#' @description 
-#' The section title or description will be used in the formal validation documentation. 
+#'
+#' @description
+#' The section title or description will be used in the formal validation documentation.
 #' For more information visit \url{https://www.rpact.com}
-#' 
-#' @export 
-#' 
+#'
+#' @export
+#'
 #' @keywords internal
-#' 
+#'
 test_plan_section <- function(section) {
     cat("\n\n--- ", section, " ---\n", sep = "")
 }
