@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5594 $
-## |  Last changed: $Date: 2021-11-26 15:24:35 +0100 (Fr, 26 Nov 2021) $
+## |  File version: $Revision: 7126 $
+## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -29,7 +29,7 @@ NULL
         plannedSubjects,
         allocationRatioPlanned,
         selectedArms,
-        piH1,
+        piTreatmentsH1,
         piControlH1,
         overallRates,
         overallRatesControl,
@@ -45,24 +45,24 @@ NULL
             } else {
                 piAssumedControlH1 <- piControlH1
             }
-            if (is.na(piH1)) {
+            if (is.na(piTreatmentsH1)) {
                 if (directionUpper) {
                     piAssumedH1 <- min(overallRates[selectedArms[1:gMax, stage + 1], stage], na.rm = TRUE)
                 } else {
                     piAssumedH1 <- max(overallRates[selectedArms[1:gMax, stage + 1], stage], na.rm = TRUE)
                 }
             } else {
-                piAssumedH1 <- piH1
+                piAssumedH1 <- piTreatmentsH1
             }
-            pim <- (allocationRatioPlanned * piAssumedH1 + piAssumedControlH1) / (1 + allocationRatioPlanned)
+            pim <- (allocationRatioPlanned[stage] * piAssumedH1 + piAssumedControlH1) / (1 + allocationRatioPlanned[stage])
 
             if (conditionalCriticalValue[stage] > 8) {
                 newSubjects <- maxNumberOfSubjectsPerStage[stage + 1]
             } else {
                 newSubjects <- (max(0, conditionalCriticalValue[stage] *
-                    sqrt(pim * (1 - pim) * (1 + allocationRatioPlanned)) +
+                    sqrt(pim * (1 - pim) * (1 + allocationRatioPlanned[stage])) +
                     .getQNorm(conditionalPower) * sqrt(piAssumedH1 * (1 - piAssumedH1) +
-                        piAssumedControlH1 * (1 - piAssumedControlH1) * allocationRatioPlanned)))^2 /
+                        piAssumedControlH1 * (1 - piAssumedControlH1) * allocationRatioPlanned[stage])))^2 /
                     (max(1e-7, (2 * directionUpper - 1) * (piAssumedH1 - piAssumedControlH1)))^2
                 newSubjects <- min(
                     max(minNumberOfSubjectsPerStage[stage + 1], newSubjects),
@@ -81,7 +81,7 @@ NULL
 .getSimulatedStageRatesMultiArm <- function(design, directionUpper, piVector, piControl,
         plannedSubjects, typeOfSelection, effectMeasure, adaptations, epsilonValue, rValue,
         threshold, allocationRatioPlanned, minNumberOfSubjectsPerStage,
-        maxNumberOfSubjectsPerStage, conditionalPower, piH1, piControlH1,
+        maxNumberOfSubjectsPerStage, conditionalPower, piTreatmentsH1, piControlH1,
         calcSubjectsFunction, calcSubjectsFunctionIsUserDefined, selectArmsFunction) {
     kMax <- length(plannedSubjects)
     gMax <- length(piVector)
@@ -107,9 +107,9 @@ NULL
 
     for (k in (1:kMax)) {
         if (k == 1) {
-            subjectsPerStage[gMax + 1, k] <- trunc(plannedSubjects[k] / allocationRatioPlanned)
+            subjectsPerStage[gMax + 1, k] <- trunc(plannedSubjects[k] / allocationRatioPlanned[k])
         } else {
-            subjectsPerStage[gMax + 1, k] <- trunc((plannedSubjects[k] - plannedSubjects[k - 1]) / allocationRatioPlanned)
+            subjectsPerStage[gMax + 1, k] <- trunc((plannedSubjects[k] - plannedSubjects[k - 1]) / allocationRatioPlanned[k])
         }
         simRates[gMax + 1, k] <- stats::rbinom(1, subjectsPerStage[gMax + 1, k], piControl) / subjectsPerStage[gMax + 1, k]
 
@@ -147,8 +147,8 @@ NULL
                 overallEffectSizes[treatmentArm, k] <- (2 * directionUpper - 1) *
                     (overallRates[treatmentArm, k] - overallRatesControl[k])
 
-                rmOverall <- (allocationRatioPlanned * overallRates[treatmentArm, k] +
-                    overallRatesControl[k]) / (allocationRatioPlanned + 1)
+                rmOverall <- (allocationRatioPlanned[k] * overallRates[treatmentArm, k] +
+                    overallRatesControl[k]) / (allocationRatioPlanned[k] + 1)
 
                 if (overallEffectSizes[treatmentArm, k] == 0) {
                     overallTestStatistics[treatmentArm, k] <- 0
@@ -192,12 +192,12 @@ NULL
             if (adaptations[k]) {
                 if (effectMeasure == "testStatistic") {
                     selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(
-                        k, overallTestStatistics[, k] + runif(gMax, -1E-5, 1E-5),
+                        k, overallTestStatistics[, k] + runif(gMax, -1e-05, 1e-05),
                         typeOfSelection, epsilonValue, rValue, threshold, selectArmsFunction
                     ))
                 } else if (effectMeasure == "effectEstimate") {
                     selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(
-                        k, overallEffectSizes[, k] + runif(gMax, -1E-5, 1E-5),
+                        k, overallEffectSizes[, k] + runif(gMax, -1e-05, 1e-05),
                         typeOfSelection, epsilonValue, rValue, threshold, selectArmsFunction
                     ))
                 }
@@ -210,7 +210,7 @@ NULL
                     plannedSubjects = plannedSubjects,
                     allocationRatioPlanned = allocationRatioPlanned,
                     selectedArms = selectedArms,
-                    piH1 = piH1,
+                    piTreatmentsH1 = piTreatmentsH1,
                     piControlH1 = piControlH1,
                     overallRates = overallRates,
                     overallRatesControl = overallRatesControl,
@@ -227,8 +227,8 @@ NULL
                 }
 
                 if (!is.na(conditionalPower) || calcSubjectsFunctionIsUserDefined) {
-                    plannedSubjects[(k + 1):kMax] <- ceiling(sum(subjectsPerStage[gMax + 1, 1:k]) *
-                        allocationRatioPlanned + cumsum(rep(newSubjects, kMax - k)))
+                    plannedSubjects[(k + 1):kMax] <- ceiling(sum(subjectsPerStage[gMax + 1, 1:k] *
+                        allocationRatioPlanned[1:k]) + cumsum(rep(newSubjects, kMax - k)))
                 }
             } else {
                 selectedArms[, k + 1] <- selectedArms[, k]
@@ -240,37 +240,37 @@ NULL
                 piAssumedControlH1 <- piControlH1
             }
 
-            if (is.na(piH1)) {
+            if (is.na(piTreatmentsH1)) {
                 if (directionUpper) {
                     piAssumedH1 <- min(overallRates[selectedArms[1:gMax, k], k], na.rm = TRUE)
                 } else {
                     piAssumedH1 <- max(overallRates[selectedArms[1:gMax, k], k], na.rm = TRUE)
                 }
             } else {
-                piAssumedH1 <- piH1
+                piAssumedH1 <- piTreatmentsH1
             }
 
-            pim <- (allocationRatioPlanned * piAssumedH1 + piAssumedControlH1) / (1 + allocationRatioPlanned)
+            pim <- (allocationRatioPlanned[k] * piAssumedH1 + piAssumedControlH1) / (1 + allocationRatioPlanned[k])
 
             if (piAssumedH1 * (1 - piAssumedH1) + piAssumedControlH1 * (1 - piAssumedControlH1) == 0) {
                 thetaStandardized <- 0
             } else {
-                thetaStandardized <- sqrt(allocationRatioPlanned) / (1 + allocationRatioPlanned) * (
-                    (piAssumedH1 - piAssumedControlH1) * sqrt(1 + allocationRatioPlanned) /
-                        sqrt(piAssumedH1 * (1 - piAssumedH1) + allocationRatioPlanned *
+                thetaStandardized <- sqrt(allocationRatioPlanned[k]) / (1 + allocationRatioPlanned[k]) *
+                    ((piAssumedH1 - piAssumedControlH1) * sqrt(1 + allocationRatioPlanned[k]) /
+                        sqrt(piAssumedH1 * (1 - piAssumedH1) + allocationRatioPlanned[k] *
                             piAssumedControlH1 * (1 - piAssumedControlH1)) +
                         sign(piAssumedH1 - piAssumedControlH1) * conditionalCriticalValue[k] *
-                            (1 - sqrt(pim * (1 - pim) + allocationRatioPlanned * pim * (1 - pim)) /
-                                sqrt(piAssumedH1 * (1 - piAssumedH1) + allocationRatioPlanned *
+                            (1 - sqrt(pim * (1 - pim) + allocationRatioPlanned[k] * pim * (1 - pim)) /
+                                sqrt(piAssumedH1 * (1 - piAssumedH1) + allocationRatioPlanned[k] *
                                     piAssumedControlH1 * (1 - piAssumedControlH1))) *
-                            sqrt((1 + allocationRatioPlanned) / (plannedSubjects[k + 1] - plannedSubjects[k]))
-                )
+                            sqrt((1 + allocationRatioPlanned[k]) / (plannedSubjects[k + 1] - plannedSubjects[k]))
+                    )
             }
 
             thetaStandardized <- (2 * directionUpper - 1) * thetaStandardized
 
             conditionalPowerPerStage[k] <- 1 - stats::pnorm(conditionalCriticalValue[k] -
-                thetaStandardized * sqrt((1 + allocationRatioPlanned) / allocationRatioPlanned) *
+                thetaStandardized * sqrt((1 + allocationRatioPlanned[k]) / allocationRatioPlanned[k]) *
                     sqrt(plannedSubjects[k + 1] - plannedSubjects[k]))
         }
     }
@@ -303,7 +303,7 @@ NULL
 #'        default is \code{seq(0, 1, 0.2)}.
 #' @param piControl If specified, the assumed probability in the control arm
 #'        for simulation and under which the sample size recalculation is performed.
-#' @param piH1 If specified, the assumed probability in the active treatment arm(s)
+#' @param piTreatmentsH1 If specified, the assumed probability in the active treatment arm(s)
 #'        under which the sample size recalculation is performed.
 #' @param piControlH1 If specified, the assumed probability in the reference group
 #'        (if different from \code{piControl}) for which the conditional power was calculated.
@@ -361,7 +361,7 @@ NULL
 #' \code{conditionalCriticalValue},
 #' \code{overallRates},
 #' \code{overallRatesControl},
-#' \code{piH1}, and
+#' \code{piTreatmentsH1}, and
 #' \code{piControlH1}.
 #' The function has to contain the three-dots argument '...' (see examples).
 #'
@@ -394,7 +394,7 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
         minNumberOfSubjectsPerStage = NA_real_,
         maxNumberOfSubjectsPerStage = NA_real_,
         conditionalPower = NA_real_,
-        piH1 = NA_real_,
+        piTreatmentsH1 = NA_real_,
         piControlH1 = NA_real_,
         maxNumberOfIterations = 1000L, # C_MAX_SIMULATION_ITERATIONS_DEFAULT
         seed = NA_real_,
@@ -446,7 +446,7 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
         minNumberOfSubjectsPerStage = minNumberOfSubjectsPerStage, # means + rates only
         maxNumberOfSubjectsPerStage = maxNumberOfSubjectsPerStage, # means + rates only
         conditionalPower            = conditionalPower,
-        piH1                        = piH1, # rates only
+        piTreatmentsH1              = piTreatmentsH1, # rates only
         piControlH1                 = piControlH1, # rates only
         maxNumberOfIterations       = maxNumberOfIterations,
         seed                        = seed,
@@ -467,7 +467,7 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
     effectMatrix <- t(simulationResults$effectMatrix)
     piMaxVector <- simulationResults$piMaxVector # rates only
     piControl <- simulationResults$piControl # rates only
-    piH1 <- simulationResults$piH1 # rates only
+    piTreatmentsH1 <- simulationResults$piTreatmentsH1 # rates only
     piControlH1 <- simulationResults$piControlH1 # rates only
     conditionalPower <- simulationResults$conditionalPower
     minNumberOfSubjectsPerStage <- simulationResults$minNumberOfSubjectsPerStage
@@ -475,6 +475,10 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
     allocationRatioPlanned <- simulationResults$allocationRatioPlanned
     calcSubjectsFunction <- simulationResults$calcSubjectsFunction
 
+    if (length(allocationRatioPlanned) == 1) {
+        allocationRatioPlanned <- rep(allocationRatioPlanned, kMax)
+    }
+
     indices <- .getIndicesOfClosedHypothesesSystemForSimulation(gMax = gMax)
 
     if (.isTrialDesignConditionalDunnett(design)) {
@@ -538,7 +542,7 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
                 minNumberOfSubjectsPerStage = minNumberOfSubjectsPerStage,
                 maxNumberOfSubjectsPerStage = maxNumberOfSubjectsPerStage,
                 conditionalPower = conditionalPower,
-                piH1 = piH1,
+                piTreatmentsH1 = piTreatmentsH1,
                 piControlH1 = piControlH1,
                 calcSubjectsFunction = calcSubjectsFunction,
                 calcSubjectsFunctionIsUserDefined = calcSubjectsFunctionIsUserDefined,
