@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5594 $
-## |  Last changed: $Date: 2021-11-26 15:24:35 +0100 (Fr, 26 Nov 2021) $
+## |  File version: $Revision: 7126 $
+## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -51,16 +51,16 @@ NULL
                     ), 1 - 1e-07))
                 }
             } else {
-				if (directionUpper) {
-					thetaStandardized <- log(max(thetaH1, 1 + 1e-07))
-				} else {
-					thetaStandardized <- log(min(thetaH1, 1 - 1e-07))
-				}	
+                if (directionUpper) {
+                    thetaStandardized <- log(max(thetaH1, 1 + 1e-07))
+                } else {
+                    thetaStandardized <- log(min(thetaH1, 1 - 1e-07))
+                }
             }
             if (conditionalCriticalValue[stage] > 8) {
                 newEvents <- maxNumberOfEventsPerStage[stage + 1]
             } else {
-                newEvents <- (1 + allocationRatioPlanned)^2 / allocationRatioPlanned *
+                newEvents <- (1 + allocationRatioPlanned[stage])^2 / allocationRatioPlanned[stage] *
                     (max(0, conditionalCriticalValue[stage] +
                         .getQNorm(conditionalPower), na.rm = TRUE))^2 / thetaStandardized^2
                 newEvents <- min(
@@ -83,10 +83,10 @@ NULL
         k,
         omegaVector) {
     selectedArmsVec <- selectedArms[, k]
-    probabilityVector <- allocationRatioPlanned * omegaVector[selectedArmsVec] /
-        (1 + allocationRatioPlanned * sum(omegaVector[selectedArmsVec]))
+    probabilityVector <- allocationRatioPlanned[k] * omegaVector[selectedArmsVec] /
+        (1 + allocationRatioPlanned[k] * sum(omegaVector[selectedArmsVec]))
     armsSelected <- sum(selectedArmsVec)
-    p0 <- 1 / (1 + allocationRatioPlanned * sum(omegaVector[selectedArmsVec]))
+    p0 <- 1 / (1 + allocationRatioPlanned[k] * sum(omegaVector[selectedArmsVec]))
     covMatrix <- matrix(rep(1 / p0, armsSelected^2), ncol = armsSelected, nrow = armsSelected)
     diag(covMatrix) <- 1 / p0 + 1 / probabilityVector
     corrMatrix <- cov2cor(covMatrix)
@@ -142,12 +142,12 @@ NULL
             if (selectedArms[treatmentArm, k]) {
                 if (k == 1) {
                     eventsPerStage[treatmentArm, k] <- plannedEvents[k] *
-                        (allocationRatioPlanned * omegaVector[treatmentArm] + 1) /
-                        (allocationRatioPlanned * sum(omegaVector) + 1)
+                        (allocationRatioPlanned[k] * omegaVector[treatmentArm] + 1) /
+                        (allocationRatioPlanned[k] * sum(omegaVector) + 1)
                 } else {
                     eventsPerStage[treatmentArm, k] <- (plannedEvents[k] - plannedEvents[k - 1]) *
-                        (allocationRatioPlanned * omegaVector[treatmentArm] + 1) /
-                        (allocationRatioPlanned * sum(omegaVector[selectedArms[, k]]) + 1)
+                        (allocationRatioPlanned[k] * omegaVector[treatmentArm] + 1) /
+                        (allocationRatioPlanned[k] * sum(omegaVector[selectedArms[, k]]) + 1)
                 }
                 if (eventsPerStage[treatmentArm, k] > 0) {
                     testStatistics[treatmentArm, k] <- stats::rnorm(1, 0, 1)
@@ -175,7 +175,7 @@ NULL
             if (selectedArms[treatmentArm, k]) {
                 testStatistics[treatmentArm, k] <- testStatistics[treatmentArm, k] +
                     (2 * directionUpper - 1) * log(omegaVector[treatmentArm]) * sqrt(eventsPerStage[treatmentArm, k]) *
-                        sqrt(allocationRatioPlanned) / (1 + allocationRatioPlanned)
+                        sqrt(allocationRatioPlanned[k]) / (1 + allocationRatioPlanned[k])
 
                 separatePValues[treatmentArm, k] <- 1 - stats::pnorm(testStatistics[treatmentArm, k])
 
@@ -183,7 +183,7 @@ NULL
                     testStatistics[treatmentArm, 1:k] / sqrt(sum(eventsPerStage[treatmentArm, 1:k]))
 
                 overallEffects[treatmentArm, k] <- exp((2 * directionUpper - 1) * overallTestStatistics[treatmentArm, k] *
-                    (1 + allocationRatioPlanned) / sqrt(allocationRatioPlanned) /
+                    (1 + allocationRatioPlanned[k]) / sqrt(allocationRatioPlanned[k]) /
                     sqrt(sum(eventsPerStage[treatmentArm, 1:k])))
             }
         }
@@ -269,7 +269,7 @@ NULL
 
             conditionalPowerPerStage[k] <- 1 - stats::pnorm(conditionalCriticalValue[k] -
                 thetaStandardized * sqrt(plannedEvents[k + 1] - plannedEvents[k]) *
-                    sqrt(allocationRatioPlanned) / (1 + allocationRatioPlanned))
+                    sqrt(allocationRatioPlanned[k]) / (1 + allocationRatioPlanned[k]))
         }
     }
 
@@ -467,6 +467,10 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
     allocationRatioPlanned <- simulationResults$allocationRatioPlanned
     calcEventsFunction <- simulationResults$calcEventsFunction
 
+    if (length(allocationRatioPlanned) == 1) {
+        allocationRatioPlanned <- rep(allocationRatioPlanned, kMax)
+    }
+
     simulationResults$correlationComputation <- correlationComputation
     if (correlationComputation != "alternative") {
         simulationResults$.setParameterType("correlationComputation", C_PARAM_USER_DEFINED)
@@ -517,7 +521,7 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
     choleskyDecomposition <- NULL
 
     if (correlationComputation == "null") {
-        # Not accounting for alternative
+        # not accounting for alternative
         corrMatrix <- matrix(rep(allocationRatioPlanned / (1 + allocationRatioPlanned), gMax^2), ncol = gMax, nrow = gMax)
         diag(corrMatrix) <- 1
         choleskyDecomposition <- chol(corrMatrix)
@@ -597,9 +601,31 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
                 if (k == 1) {
                     simulatedOverallEventsPerStage[k, i] <- simulatedOverallEventsPerStage[k, i] +
                         stageResults$plannedEvents[k]
+                    for (g in 1:gMax) {
+                        if (closedTest$selectedArms[g, k]) {
+                            simulatedSingleEventsPerStage[k, i, g] <- simulatedSingleEventsPerStage[k, i, g] +
+                                stageResults$plannedEvents[k] *
+                                    allocationRatioPlanned[k] * effectMatrix[i, g] / (1 + allocationRatioPlanned[k] *
+                                        sum(effectMatrix[i, closedTest$selectedArms[, k]]))
+                        }
+                    }
+                    simulatedSingleEventsPerStage[k, i, gMax + 1] <- simulatedSingleEventsPerStage[k, i, gMax + 1] +
+                        stageResults$plannedEvents[k] /
+                            (1 + allocationRatioPlanned[k] * sum(effectMatrix[i, closedTest$selectedArms[, k]]))
                 } else {
                     simulatedOverallEventsPerStage[k, i] <- simulatedOverallEventsPerStage[k, i] +
                         stageResults$plannedEvents[k] - stageResults$plannedEvents[k - 1]
+                    for (g in 1:gMax) {
+                        if (closedTest$selectedArms[g, k]) {
+                            simulatedSingleEventsPerStage[k, i, g] <- simulatedSingleEventsPerStage[k, i, g] +
+                                (stageResults$plannedEvents[k] - stageResults$plannedEvents[k - 1]) *
+                                    allocationRatioPlanned[k] * effectMatrix[i, g] / (1 + allocationRatioPlanned[k] *
+                                        sum(effectMatrix[i, closedTest$selectedArms[, k]]))
+                        }
+                    }
+                    simulatedSingleEventsPerStage[k, i, gMax + 1] <- simulatedSingleEventsPerStage[k, i, gMax + 1] +
+                        (stageResults$plannedEvents[k] - stageResults$plannedEvents[k - 1]) /
+                            (1 + allocationRatioPlanned[k] * sum(effectMatrix[i, closedTest$selectedArms[, k]]))
                 }
 
                 for (g in 1:gMax) {
@@ -642,13 +668,7 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
         }
 
         simulatedOverallEventsPerStage[, i] <- simulatedOverallEventsPerStage[, i] / iterations[, i]
-
-        for (g in 1:gMax) {
-            simulatedSingleEventsPerStage[, i, g] <- simulatedOverallEventsPerStage[, i] *
-                allocationRatioPlanned * effectMatrix[i, g] / (1 + allocationRatioPlanned * sum(effectMatrix[i, ]))
-        }
-        simulatedSingleEventsPerStage[, i, gMax + 1] <- simulatedOverallEventsPerStage[, i] /
-            (1 + allocationRatioPlanned * sum(effectMatrix[i, ]))
+        simulatedSingleEventsPerStage[, i, ] <- simulatedSingleEventsPerStage[, i, ] / iterations[, i]
 
         if (kMax > 1) {
             simulatedRejections[2:kMax, i, ] <- simulatedRejections[2:kMax, i, ] - simulatedRejections[1:(kMax - 1), i, ]
