@@ -14,16 +14,19 @@
 ## |  Contact us for information about our services: info@rpact.com
 ## |  
 ## |  File name: test-f_simulation_enrichment_means.R
-## |  Creation date: 23 February 2022, 14:06:45
-## |  File version: $Revision: 6279 $
-## |  Last changed: $Date: 2022-06-09 17:48:13 +0200 (Thu, 09 Jun 2022) $
+## |  Creation date: 06 February 2023, 12:13:59
+## |  File version: $Revision: 6810 $
+## |  Last changed: $Date: 2023-02-13 12:58:47 +0100 (Mo, 13 Feb 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |  
 
-context("Testing Simulation Enrichment Means Function")
+test_plan_section("Testing Simulation Enrichment Means Function")
 
 
 test_that("'getSimulationEnrichmentMeans': gMax = 2", {
+        
+    .skipTestIfDisabled()
+        
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:subsec:intersectionTestsEnrichment}
@@ -59,7 +62,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 2", {
 	design <- getDesignInverseNormal(informationRates = c(0.3, 1), typeOfDesign = "asUser", userAlphaSpending = c(0.01, 0.025))
 
 	suppressWarnings(simResult1 <- getSimulationEnrichmentMeans(design,
-	    populations = 2,
 	    plannedSubjects = c(60, 160), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 0.5,
 	    typeOfSelection = "epsilon", epsilonValue = 0.1,
@@ -108,11 +110,8 @@ test_that("'getSimulationEnrichmentMeans': gMax = 2", {
 	    expect_true(is.matrix(mtx))
 	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
-    
-    .skipTestIfDisabled()
 
 	suppressWarnings(simResult2 <- getSimulationEnrichmentMeans(design,
-	    populations = 2,
 	    plannedSubjects = c(60, 160), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 0.5,
 	    typeOfSelection = "rBest", rValue = 2,
@@ -163,7 +162,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 2", {
 	}
 
 	suppressWarnings(simResult3 <- getSimulationEnrichmentMeans(design,
-	    populations = 2,
 	    plannedSubjects = c(60, 160), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 0.5,
 	    typeOfSelection = "all",
@@ -214,7 +212,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 2", {
 	}
 
 	suppressWarnings(simResult4 <- getSimulationEnrichmentMeans(design,
-	    populations = 2,
 	    plannedSubjects = c(60, 160), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 0.5,
 	    typeOfSelection = "epsilon", epsilonValue = 0.1,
@@ -268,8 +265,8 @@ test_that("'getSimulationEnrichmentMeans': gMax = 2", {
 
 test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 
-    .skipTestIfDisabled()
-        
+	.skipTestIfDisabled()
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:subsec:intersectionTestsEnrichment}
@@ -286,7 +283,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 	# @refFS[Formula]{fs:simulationEnrichmentSelections}
 	# @refFS[Formula]{fs:simulatingEnrichmentEffectSpecification}
 	# @refFS[Formula]{fs:enrichmentRejectionRule}
-
 	effectList <- list(
 	    subGroups = c("S1", "S2", "S12", "R"),
 	    prevalences = c(0.05, 0.35, 0.15, 0.45),
@@ -302,7 +298,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 	design <- getDesignInverseNormal(informationRates = c(0.4, 0.8, 1), typeOfDesign = "noEarlyEfficacy")
 
 	suppressWarnings(simResult1 <- getSimulationEnrichmentMeans(design,
-	    populations = 3,
 	    plannedSubjects = c(20, 40, 50), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 2,
 	    typeOfSelection = "rBest", rValue = 2,
@@ -360,7 +355,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 	suppressWarnings(simResult2 <- getSimulationEnrichmentMeans(design,
-	    populations = 3,
 	    plannedSubjects = c(20, 40, 50), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 2,
 	    typeOfSelection = "best",
@@ -418,7 +412,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 	suppressWarnings(simResult3 <- getSimulationEnrichmentMeans(design,
-	    populations = 3,
 	    plannedSubjects = c(20, 40, 50), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 2,
 	    typeOfSelection = "epsilon", epsilonValue = 0.1,
@@ -479,8 +472,8 @@ test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 
 test_that("'getSimulationEnrichmentMeans': gMax = 4", {
 
-    .skipTestIfDisabled()
-        
+	.skipTestIfDisabled()
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:subsec:intersectionTestsEnrichment}
@@ -497,7 +490,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 4", {
 	# @refFS[Formula]{fs:simulationEnrichmentSelections}
 	# @refFS[Formula]{fs:simulatingEnrichmentEffectSpecification}
 	# @refFS[Formula]{fs:enrichmentRejectionRule}
-
 	effects <- matrix(c(2.3, 3.1, 0.9, 1.2, 2.1, 3.4, 0.9, 0.2), byrow = TRUE, ncol = 8)
 	effectList <- list(subGroups = c("S1", "S2", "S3", "S12", "S13", "S23", "S123", "R"),
 			prevalences = c(0.1, 0.05, 0.1, 0.15, 0.1, 0.15, 0.3, 0.05), effects = effects, 
@@ -506,7 +498,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 4", {
 	design <- getDesignInverseNormal(informationRates = c(0.4, 1), typeOfDesign = "noEarlyEfficacy")
 
 	suppressWarnings(simResult1 <- getSimulationEnrichmentMeans(design,
-	    populations = 4, 
 		plannedSubjects = c(100, 200), 
 		effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 2, seed = 123,
@@ -559,7 +550,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 4", {
 	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 	suppressWarnings(simResult2 <- getSimulationEnrichmentMeans(design,
-	    populations = 4, 
 		plannedSubjects = c(100, 200), 
 		effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 2, seed = 123,
@@ -615,8 +605,8 @@ test_that("'getSimulationEnrichmentMeans': gMax = 4", {
 
 test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for inverse normal", {
 
-    .skipTestIfDisabled()
-        
+	.skipTestIfDisabled()
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:sec:simulationFunctions}
@@ -627,7 +617,6 @@ test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for
 	# @refFS[Formula]{fs:simulationEnrichmentSelections}
 	# @refFS[Formula]{fs:simulatingEnrichmentEffectSpecification}
 	# @refFS[Formula]{fs:enrichmentRejectionRule}
-
 	effectSeq <- seq(0, 0.7, 0.1)
 	effects <- matrix(effectSeq, byrow = TRUE, ncol = 1)
 	effectList <- list(subGroups = "F", prevalences = 1, stDevs = 1.3, effects = effects)
@@ -635,7 +624,6 @@ test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for
 	design <- getDesignInverseNormal(informationRates = c(0.3, 1), typeOfDesign = "OF", futilityBounds = c(0.1))
 
 	suppressWarnings(x1 <- getSimulationEnrichmentMeans(design,
-	    populations = 1, 
 		plannedSubjects = c(60, 180), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 2,
 	    conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(NA, 10), maxNumberOfSubjectsPerStage = c(NA, 180), thetaH1 = 0.5,
@@ -668,9 +656,9 @@ test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for
 })
 
 test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for Fisher combination", {
-        
-    .skipTestIfDisabled()
-        
+
+	.skipTestIfDisabled()
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:sec:simulationFunctions}
@@ -681,7 +669,6 @@ test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for
 	# @refFS[Formula]{fs:simulationEnrichmentSelections}
 	# @refFS[Formula]{fs:simulatingEnrichmentEffectSpecification}
 	# @refFS[Formula]{fs:enrichmentRejectionRule}
-
 	effectSeq <- seq(0, 0.7, 0.1)
 	effects <- matrix(effectSeq, byrow = TRUE, ncol = 1)
 	effectList <- list(subGroups = "F", prevalences = 1, stDevs = 1.3, effects = effects)
@@ -689,7 +676,7 @@ test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for
 	design <- getDesignFisher(informationRates = c(0.3, 1), kMax = 2)
 
 	suppressWarnings(x1 <- getSimulationEnrichmentMeans(design,
-	    populations = 1, plannedSubjects = c(60, 180), effectList = effectList,
+	    plannedSubjects = c(60, 180), effectList = effectList,
 	    maxNumberOfIterations = 100, allocationRatioPlanned = 2,
 	    conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(NA, 10), maxNumberOfSubjectsPerStage = c(NA, 180), thetaH1 = 0.5,
 	    seed = 123
